module.exports = defineTest({
	description: 'uses parent scope for right-hand-side in for-of statement (#1539)'
});
